@@ -34,18 +34,19 @@ class IngressContext(ImmutableBaseModel):
 
 class Context(ImmutableBaseModel):
     docker_compose_path: Path
-    project_name: str
     branch_name: str
     repository_name: str
     default_image: str
+    project_name: Optional[str] = None
     ingress_for_service: Optional[str] = None
     extra_manifest_path: Optional[Path] = None
     deployment: DeploymentContext
     ingress: IngressContext
 
     @validator("project_name")
-    def project_name_matches_kubernetes_name(cls, value: str) -> str:
-        ensure_lowercase_kebab(value)
+    def project_name_matches_kubernetes_name(cls, value: Optional[str]) -> Optional[str]:
+        if value is not None:
+            ensure_lowercase_kebab(value)
 
         return value
 
@@ -63,4 +64,9 @@ class Context(ImmutableBaseModel):
 
     @property
     def manifest_prefix(self) -> str:
-        return "-".join([self.project_name, self.repository_name, self.branch_name])
+        fragments = [self.project_name, self.repository_name, self.branch_name]
+        fragments_filtered = [fragment for fragment in fragments if fragment is not None]
+
+        manifest_prefix = "-".join(fragments_filtered)
+
+        return manifest_prefix
